/*
 * Copyright (C) 2011 QitSoft Inc.
 *
 * This file is part of Qimono.
 *
 * Qimono is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.qitsoft.qimono.internal;

import org.objectweb.asm.ClassVisitor;

/**
 * The interface used for ASM class modification. The base difference with the
 * original ASM {@link org.objectweb.asm.ClassVisitor} and {@link org.objectweb.asm.ClassAdapter}
 * that the next in chain visitor is installed after the object is instantiated and
 * has a reference to class loader.
 * 
 * @author Serghei Soloviov <serj@qitsoft.com>
 */
public interface ClassModifier extends ClassVisitor {

    /**
     * Sets next class visitor in the chain of class processing and modification.
     * 
     * @param cm the next class visitor to set. This also could be a ClassModifier.
     */
    void setNextVisitor(ClassVisitor cm);
    
    /**
     * Sets the classloader used to load the class to process. Inside the Qimono
     * library this method receives only {@link QimonoClassLoader}.
     * 
     * @param classloader the classloader to associate with this modifier.
     */
    void setClassLoader(ClassLoader classloader);
    
}
