/*
 * Copyright (C) 2011 QitSoft Inc.
 *
 * This file is part of Qimono.
 *
 * Qimono is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.qitsoft.qimono.internal;

import com.qitsoft.qimono.runners.QimonoJUnitRunner;
import org.objectweb.asm.ClassAdapter;
import org.objectweb.asm.ClassVisitor;

/**
 * The base class which extends {@link ClassModifier} and mainly 
 * implements the methods declared in {@link ClassModifier} interface.
 * In almost cases is preferable to extend from this class than from 
 * {@link ClassModifier} directly.
 * 
 * @author Serghei Soloviov <serj@qitsoft.com>
 */
public class ClassModifierAdapter extends ClassAdapter implements ClassModifier {

    private ClassLoader classloader;

    /**
     * Constructs new ClassModifierAdapter. It overrides (hides) the base constructor of
     * {@link org.objectweb.asm.ClassAdapter} which accepts the next class visitor
     * to match the {@link ClassModifier} specification.
     */
    public ClassModifierAdapter() {
        super(null);
    }

    /**
     *  {@inheritDoc}
     */
    @Override
    public void setNextVisitor(ClassVisitor cm) {
        cv = cm;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void setClassLoader(ClassLoader classloader) {
        this.classloader = classloader;
    }

    /**
     * Returns the class loader associated with this modifier. In almost cases 
     * this method returns the {@link QimonoClassLoader} due to set in {@link QimonoJUnitRunner}
     * 
     * @return the class loader associated with the modifier.
     */
    protected ClassLoader getClassLoader() {
        return this.classloader;
    }


}
