/*
 * Copyright (C) 2011 QitSoft Inc.
 *
 * This file is part of Qimono.
 *
 * Qimono is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.qitsoft.qimono.internal;

import org.objectweb.asm.ClassVisitor;
import org.objectweb.asm.tree.ClassNode;

/**
 * The ASM visitor to instrument class using ASM Tree API. This class 
 * extends {@link ClassModifier} which makes it working by {@linkplain ClassModifier}
 * logic.
 * 
 * @author Serghei Soloviov <serj@qitsoft.com>
 */
public class ClassNodeModifierAdapter extends ClassNode implements ClassModifier {

    private ClassLoader classloader;
    private ClassVisitor cv;

    /**
     * {@inheritDoc}
     */
    @Override
    public void setNextVisitor(ClassVisitor cm) {
        cv = cm;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void setClassLoader(ClassLoader classloader) {
        this.classloader = classloader;
    }

    /**
     * Returns the classloader assigned to this modifier. Often the classloader
     * is of type {@link QimonoClassLoader}.
     * 
     * @return the classloader assigned to this modifier.
     */
    protected ClassLoader getClassLoader() {
        return this.classloader;
    }

    /**
     * The overrided method where the structure and modifications of class is performed
     * regarding the Asm Tree API.
     */
    @Override
    public void visitEnd() {
        super.visitEnd();
        accept(cv);
    }

}
