/*
 * Copyright (C) 2011 QitSoft Inc.
 *
 * This file is part of Qimono.
 *
 * Qimono is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.qitsoft.qimono.internal.modifiers;

/**
 * The structure which holds the class declaration. It is used in class modifiers.
 * The fields are copied from method signature {@link org.objectweb.asm.ClassVisitor#visit(int, int, java.lang.String, java.lang.String, java.lang.String, java.lang.String[]) }
 * 
 * @author Serghei Soloviov <serj@qitsoft.com>
 */
class ClassDecl {
    
    /**
     * The access modifiers of the class.
     * 
     * @see org.objectweb.asm.Opcodes
     */
    public final int modifiers;
    
    /**
     * The name of the class.
     */
    public final String name;
    
    /**
     * The signature of the class.
     */
    public final String signature;
    
    /**
     * The name of the super class.
     */
    public final String superName;
    
    /**
     * The list of names of implemented interfaces.
     */
    public final String[] interfaces;

    /**
     * Constructor used to instantiate the class and initialize it in one call.
     * 
     * @param modifiers the access modifiers.
     * @param name the name of the class.
     * @param signature the signature of the class.
     * @param superName the name of extended class.
     * @param interfaces the list of names of implemented interfaces.
     */
    public ClassDecl(int modifiers, String name, String signature, String superName, String[] interfaces) {
        this.modifiers = modifiers;
        this.name = name;
        this.signature = signature;
        this.superName = superName;
        this.interfaces = interfaces;
    }
    
}
