/*
 * Copyright (C) 2011 QitSoft Inc.
 *
 * This file is part of Qimono.
 *
 * Qimono is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.qitsoft.qimono.internal.modifiers;

import com.qitsoft.qimono.internal.RegistryMethodAdapter;

/**
 * The structure which holds the method declaration.The fields are copied from
 * {@link org.objectweb.asm.ClassVisitor#visitMethod(int, java.lang.String, java.lang.String, java.lang.String, java.lang.String[]) }.
 * 
 * @author Serghei Soloviov <serj@qitsoft.com>
 */
class MethodDecl {
    
    /**
     * The access modifiers of the method. 
     * 
     * @see org.objectweb.asm.Opcodes
     */
    public final int modifiers;
    
    /**
     * The name of the method.
     */
    public final String name;
    
    /**
     * The descriptor of the method.
     */
    public final String desc;
    
    /**
     * The signature of the method.
     */
    public final String signature;
    
    /**
     * The list of checked exceptions thrown by the method.
     */
    public final String[] exceptions;
    
    /**
     * The registry method visitor. 
     */
    public final RegistryMethodAdapter adapter;

    /**
     * The constructor used to instantiate the class with the field's values.
     * 
     * @param modifiers the access modifiers of the method.
     * @param name the name of the method.
     * @param desc the descriptor of the method.
     * @param signature the signature of the method.
     * @param exceptions thrown exceptions by the method.
     * @param adapter the registry adapter used by this structure.
     */
    public MethodDecl(int modifiers, String name, String desc, String signature, String[] exceptions, RegistryMethodAdapter adapter) {
        this.modifiers = modifiers;
        this.name = name;
        this.desc = desc;
        this.signature = signature;
        this.exceptions = exceptions;
        this.adapter = adapter;
    }
    
}
