/*
 * Copyright (C) 2011 QitSoft Inc.
 *
 * This file is part of Qimono.
 *
 * Qimono is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.qitsoft.qimono.internal.modifiers;

import com.qitsoft.qimono.internal.ClassModifierUtils;
import com.qitsoft.qimono.internal.ClassModifierAdapter;
import org.objectweb.asm.FieldVisitor;
import org.objectweb.asm.Opcodes;

/**
 * Class Modifier used to make all non public field to be public.
 * 
 * @author Serghei Soloviov <serj@qitsoft.com>
 */
public class NonPublicFieldsModifier extends ClassModifierAdapter {

    /**
     * {@inheritDoc }
     */
    @Override
    public FieldVisitor visitField(int access, String name, String desc, String signature, Object value) {
        int newAccess;
        if ((access & Opcodes.ACC_FINAL) != 0
                || (access & Opcodes.ACC_STATIC) != 0) {
            newAccess = access;
        } else {
            newAccess = ClassModifierUtils.makePublicAccess(access);
        }

        return super.visitField(newAccess, name, desc, signature, value);
    }

}
